# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ClusterArgs', 'Cluster']

@pulumi.input_type
class ClusterArgs:
    def __init__(__self__, *,
                 cluster_template_id: Optional[pulumi.Input[_builtins.str]] = None,
                 create_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 discovery_url: Optional[pulumi.Input[_builtins.str]] = None,
                 docker_volume_size: Optional[pulumi.Input[_builtins.int]] = None,
                 fixed_network: Optional[pulumi.Input[_builtins.str]] = None,
                 fixed_subnet: Optional[pulumi.Input[_builtins.str]] = None,
                 flavor: Optional[pulumi.Input[_builtins.str]] = None,
                 floating_ip_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 keypair: Optional[pulumi.Input[_builtins.str]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 master_count: Optional[pulumi.Input[_builtins.int]] = None,
                 master_flavor: Optional[pulumi.Input[_builtins.str]] = None,
                 master_lb_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 merge_labels: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_count: Optional[pulumi.Input[_builtins.int]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Cluster resource.
        :param pulumi.Input[_builtins.str] cluster_template_id: The UUID of the V1 Container Infra cluster
               template. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.int] create_timeout: The timeout (in minutes) for creating the
               cluster. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] discovery_url: The URL used for cluster node discovery.
               Changing this creates a new cluster.
        :param pulumi.Input[_builtins.int] docker_volume_size: The size (in GB) of the Docker volume.
               Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] fixed_network: The fixed network that will be attached to the
               cluster. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] fixed_subnet: The fixed subnet that will be attached to the
               cluster. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] flavor: The flavor for the nodes of the cluster. Can be set via
               the `OS_MAGNUM_FLAVOR` environment variable. Changing this creates a new
               cluster.
        :param pulumi.Input[_builtins.bool] floating_ip_enabled: Indicates whether floating IP should be
               created for every cluster node. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] keypair: The name of the Compute service SSH keypair. Changing
               this creates a new cluster.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] labels: The list of key value pairs representing additional
               properties of the cluster. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.int] master_count: The number of master nodes for the cluster.
               Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] master_flavor: The flavor for the master nodes. Can be set via
               the `OS_MAGNUM_MASTER_FLAVOR` environment variable. Changing this creates a
               new cluster.
        :param pulumi.Input[_builtins.bool] master_lb_enabled: Indicates whether to create a load balancer
               for the master nodes. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.bool] merge_labels: Indicates whether the provided labels should be
               merged with cluster template labels. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] name: The name of the cluster. Changing this creates a new
               cluster.
        :param pulumi.Input[_builtins.int] node_count: The number of nodes for the cluster.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V1 Container Infra
               client. A Container Infra client is needed to create a cluster. If omitted,
               the `region` argument of the provider is used. Changing this creates a new
               cluster.
        """
        if cluster_template_id is not None:
            pulumi.set(__self__, "cluster_template_id", cluster_template_id)
        if create_timeout is not None:
            pulumi.set(__self__, "create_timeout", create_timeout)
        if discovery_url is not None:
            pulumi.set(__self__, "discovery_url", discovery_url)
        if docker_volume_size is not None:
            pulumi.set(__self__, "docker_volume_size", docker_volume_size)
        if fixed_network is not None:
            pulumi.set(__self__, "fixed_network", fixed_network)
        if fixed_subnet is not None:
            pulumi.set(__self__, "fixed_subnet", fixed_subnet)
        if flavor is not None:
            pulumi.set(__self__, "flavor", flavor)
        if floating_ip_enabled is not None:
            pulumi.set(__self__, "floating_ip_enabled", floating_ip_enabled)
        if keypair is not None:
            pulumi.set(__self__, "keypair", keypair)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if master_count is not None:
            pulumi.set(__self__, "master_count", master_count)
        if master_flavor is not None:
            pulumi.set(__self__, "master_flavor", master_flavor)
        if master_lb_enabled is not None:
            pulumi.set(__self__, "master_lb_enabled", master_lb_enabled)
        if merge_labels is not None:
            pulumi.set(__self__, "merge_labels", merge_labels)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if node_count is not None:
            pulumi.set(__self__, "node_count", node_count)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter(name="clusterTemplateId")
    def cluster_template_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The UUID of the V1 Container Infra cluster
        template. Changing this creates a new cluster.
        """
        return pulumi.get(self, "cluster_template_id")

    @cluster_template_id.setter
    def cluster_template_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cluster_template_id", value)

    @_builtins.property
    @pulumi.getter(name="createTimeout")
    def create_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The timeout (in minutes) for creating the
        cluster. Changing this creates a new cluster.
        """
        return pulumi.get(self, "create_timeout")

    @create_timeout.setter
    def create_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "create_timeout", value)

    @_builtins.property
    @pulumi.getter(name="discoveryUrl")
    def discovery_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The URL used for cluster node discovery.
        Changing this creates a new cluster.
        """
        return pulumi.get(self, "discovery_url")

    @discovery_url.setter
    def discovery_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "discovery_url", value)

    @_builtins.property
    @pulumi.getter(name="dockerVolumeSize")
    def docker_volume_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The size (in GB) of the Docker volume.
        Changing this creates a new cluster.
        """
        return pulumi.get(self, "docker_volume_size")

    @docker_volume_size.setter
    def docker_volume_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "docker_volume_size", value)

    @_builtins.property
    @pulumi.getter(name="fixedNetwork")
    def fixed_network(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The fixed network that will be attached to the
        cluster. Changing this creates a new cluster.
        """
        return pulumi.get(self, "fixed_network")

    @fixed_network.setter
    def fixed_network(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "fixed_network", value)

    @_builtins.property
    @pulumi.getter(name="fixedSubnet")
    def fixed_subnet(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The fixed subnet that will be attached to the
        cluster. Changing this creates a new cluster.
        """
        return pulumi.get(self, "fixed_subnet")

    @fixed_subnet.setter
    def fixed_subnet(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "fixed_subnet", value)

    @_builtins.property
    @pulumi.getter
    def flavor(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The flavor for the nodes of the cluster. Can be set via
        the `OS_MAGNUM_FLAVOR` environment variable. Changing this creates a new
        cluster.
        """
        return pulumi.get(self, "flavor")

    @flavor.setter
    def flavor(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "flavor", value)

    @_builtins.property
    @pulumi.getter(name="floatingIpEnabled")
    def floating_ip_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether floating IP should be
        created for every cluster node. Changing this creates a new cluster.
        """
        return pulumi.get(self, "floating_ip_enabled")

    @floating_ip_enabled.setter
    def floating_ip_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "floating_ip_enabled", value)

    @_builtins.property
    @pulumi.getter
    def keypair(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Compute service SSH keypair. Changing
        this creates a new cluster.
        """
        return pulumi.get(self, "keypair")

    @keypair.setter
    def keypair(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "keypair", value)

    @_builtins.property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        The list of key value pairs representing additional
        properties of the cluster. Changing this creates a new cluster.
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "labels", value)

    @_builtins.property
    @pulumi.getter(name="masterCount")
    def master_count(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of master nodes for the cluster.
        Changing this creates a new cluster.
        """
        return pulumi.get(self, "master_count")

    @master_count.setter
    def master_count(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "master_count", value)

    @_builtins.property
    @pulumi.getter(name="masterFlavor")
    def master_flavor(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The flavor for the master nodes. Can be set via
        the `OS_MAGNUM_MASTER_FLAVOR` environment variable. Changing this creates a
        new cluster.
        """
        return pulumi.get(self, "master_flavor")

    @master_flavor.setter
    def master_flavor(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "master_flavor", value)

    @_builtins.property
    @pulumi.getter(name="masterLbEnabled")
    def master_lb_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether to create a load balancer
        for the master nodes. Changing this creates a new cluster.
        """
        return pulumi.get(self, "master_lb_enabled")

    @master_lb_enabled.setter
    def master_lb_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "master_lb_enabled", value)

    @_builtins.property
    @pulumi.getter(name="mergeLabels")
    def merge_labels(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the provided labels should be
        merged with cluster template labels. Changing this creates a new cluster.
        """
        return pulumi.get(self, "merge_labels")

    @merge_labels.setter
    def merge_labels(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "merge_labels", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the cluster. Changing this creates a new
        cluster.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="nodeCount")
    def node_count(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of nodes for the cluster.
        """
        return pulumi.get(self, "node_count")

    @node_count.setter
    def node_count(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "node_count", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V1 Container Infra
        client. A Container Infra client is needed to create a cluster. If omitted,
        the `region` argument of the provider is used. Changing this creates a new
        cluster.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _ClusterState:
    def __init__(__self__, *,
                 api_address: Optional[pulumi.Input[_builtins.str]] = None,
                 cluster_template_id: Optional[pulumi.Input[_builtins.str]] = None,
                 coe_version: Optional[pulumi.Input[_builtins.str]] = None,
                 container_version: Optional[pulumi.Input[_builtins.str]] = None,
                 create_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 discovery_url: Optional[pulumi.Input[_builtins.str]] = None,
                 docker_volume_size: Optional[pulumi.Input[_builtins.int]] = None,
                 fixed_network: Optional[pulumi.Input[_builtins.str]] = None,
                 fixed_subnet: Optional[pulumi.Input[_builtins.str]] = None,
                 flavor: Optional[pulumi.Input[_builtins.str]] = None,
                 floating_ip_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 keypair: Optional[pulumi.Input[_builtins.str]] = None,
                 kubeconfig: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 master_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 master_count: Optional[pulumi.Input[_builtins.int]] = None,
                 master_flavor: Optional[pulumi.Input[_builtins.str]] = None,
                 master_lb_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 merge_labels: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 node_count: Optional[pulumi.Input[_builtins.int]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 stack_id: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Cluster resources.
        :param pulumi.Input[_builtins.str] cluster_template_id: The UUID of the V1 Container Infra cluster
               template. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.int] create_timeout: The timeout (in minutes) for creating the
               cluster. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] discovery_url: The URL used for cluster node discovery.
               Changing this creates a new cluster.
        :param pulumi.Input[_builtins.int] docker_volume_size: The size (in GB) of the Docker volume.
               Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] fixed_network: The fixed network that will be attached to the
               cluster. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] fixed_subnet: The fixed subnet that will be attached to the
               cluster. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] flavor: The flavor for the nodes of the cluster. Can be set via
               the `OS_MAGNUM_FLAVOR` environment variable. Changing this creates a new
               cluster.
        :param pulumi.Input[_builtins.bool] floating_ip_enabled: Indicates whether floating IP should be
               created for every cluster node. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] keypair: The name of the Compute service SSH keypair. Changing
               this creates a new cluster.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] labels: The list of key value pairs representing additional
               properties of the cluster. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.int] master_count: The number of master nodes for the cluster.
               Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] master_flavor: The flavor for the master nodes. Can be set via
               the `OS_MAGNUM_MASTER_FLAVOR` environment variable. Changing this creates a
               new cluster.
        :param pulumi.Input[_builtins.bool] master_lb_enabled: Indicates whether to create a load balancer
               for the master nodes. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.bool] merge_labels: Indicates whether the provided labels should be
               merged with cluster template labels. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] name: The name of the cluster. Changing this creates a new
               cluster.
        :param pulumi.Input[_builtins.int] node_count: The number of nodes for the cluster.
        :param pulumi.Input[_builtins.str] project_id: The project of the cluster. Required if admin wants
               to create a cluster in another project. Changing this creates a new
               cluster.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V1 Container Infra
               client. A Container Infra client is needed to create a cluster. If omitted,
               the `region` argument of the provider is used. Changing this creates a new
               cluster.
        :param pulumi.Input[_builtins.str] user_id: The user of the cluster. Required if admin wants to
               create a cluster template for another user. Changing this creates a new
               cluster.
        """
        if api_address is not None:
            pulumi.set(__self__, "api_address", api_address)
        if cluster_template_id is not None:
            pulumi.set(__self__, "cluster_template_id", cluster_template_id)
        if coe_version is not None:
            pulumi.set(__self__, "coe_version", coe_version)
        if container_version is not None:
            pulumi.set(__self__, "container_version", container_version)
        if create_timeout is not None:
            pulumi.set(__self__, "create_timeout", create_timeout)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if discovery_url is not None:
            pulumi.set(__self__, "discovery_url", discovery_url)
        if docker_volume_size is not None:
            pulumi.set(__self__, "docker_volume_size", docker_volume_size)
        if fixed_network is not None:
            pulumi.set(__self__, "fixed_network", fixed_network)
        if fixed_subnet is not None:
            pulumi.set(__self__, "fixed_subnet", fixed_subnet)
        if flavor is not None:
            pulumi.set(__self__, "flavor", flavor)
        if floating_ip_enabled is not None:
            pulumi.set(__self__, "floating_ip_enabled", floating_ip_enabled)
        if keypair is not None:
            pulumi.set(__self__, "keypair", keypair)
        if kubeconfig is not None:
            pulumi.set(__self__, "kubeconfig", kubeconfig)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if master_addresses is not None:
            pulumi.set(__self__, "master_addresses", master_addresses)
        if master_count is not None:
            pulumi.set(__self__, "master_count", master_count)
        if master_flavor is not None:
            pulumi.set(__self__, "master_flavor", master_flavor)
        if master_lb_enabled is not None:
            pulumi.set(__self__, "master_lb_enabled", master_lb_enabled)
        if merge_labels is not None:
            pulumi.set(__self__, "merge_labels", merge_labels)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if node_addresses is not None:
            pulumi.set(__self__, "node_addresses", node_addresses)
        if node_count is not None:
            pulumi.set(__self__, "node_count", node_count)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if stack_id is not None:
            pulumi.set(__self__, "stack_id", stack_id)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter(name="apiAddress")
    def api_address(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "api_address")

    @api_address.setter
    def api_address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "api_address", value)

    @_builtins.property
    @pulumi.getter(name="clusterTemplateId")
    def cluster_template_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The UUID of the V1 Container Infra cluster
        template. Changing this creates a new cluster.
        """
        return pulumi.get(self, "cluster_template_id")

    @cluster_template_id.setter
    def cluster_template_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cluster_template_id", value)

    @_builtins.property
    @pulumi.getter(name="coeVersion")
    def coe_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "coe_version")

    @coe_version.setter
    def coe_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "coe_version", value)

    @_builtins.property
    @pulumi.getter(name="containerVersion")
    def container_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "container_version")

    @container_version.setter
    def container_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "container_version", value)

    @_builtins.property
    @pulumi.getter(name="createTimeout")
    def create_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The timeout (in minutes) for creating the
        cluster. Changing this creates a new cluster.
        """
        return pulumi.get(self, "create_timeout")

    @create_timeout.setter
    def create_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "create_timeout", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="discoveryUrl")
    def discovery_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The URL used for cluster node discovery.
        Changing this creates a new cluster.
        """
        return pulumi.get(self, "discovery_url")

    @discovery_url.setter
    def discovery_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "discovery_url", value)

    @_builtins.property
    @pulumi.getter(name="dockerVolumeSize")
    def docker_volume_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The size (in GB) of the Docker volume.
        Changing this creates a new cluster.
        """
        return pulumi.get(self, "docker_volume_size")

    @docker_volume_size.setter
    def docker_volume_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "docker_volume_size", value)

    @_builtins.property
    @pulumi.getter(name="fixedNetwork")
    def fixed_network(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The fixed network that will be attached to the
        cluster. Changing this creates a new cluster.
        """
        return pulumi.get(self, "fixed_network")

    @fixed_network.setter
    def fixed_network(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "fixed_network", value)

    @_builtins.property
    @pulumi.getter(name="fixedSubnet")
    def fixed_subnet(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The fixed subnet that will be attached to the
        cluster. Changing this creates a new cluster.
        """
        return pulumi.get(self, "fixed_subnet")

    @fixed_subnet.setter
    def fixed_subnet(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "fixed_subnet", value)

    @_builtins.property
    @pulumi.getter
    def flavor(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The flavor for the nodes of the cluster. Can be set via
        the `OS_MAGNUM_FLAVOR` environment variable. Changing this creates a new
        cluster.
        """
        return pulumi.get(self, "flavor")

    @flavor.setter
    def flavor(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "flavor", value)

    @_builtins.property
    @pulumi.getter(name="floatingIpEnabled")
    def floating_ip_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether floating IP should be
        created for every cluster node. Changing this creates a new cluster.
        """
        return pulumi.get(self, "floating_ip_enabled")

    @floating_ip_enabled.setter
    def floating_ip_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "floating_ip_enabled", value)

    @_builtins.property
    @pulumi.getter
    def keypair(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Compute service SSH keypair. Changing
        this creates a new cluster.
        """
        return pulumi.get(self, "keypair")

    @keypair.setter
    def keypair(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "keypair", value)

    @_builtins.property
    @pulumi.getter
    def kubeconfig(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        return pulumi.get(self, "kubeconfig")

    @kubeconfig.setter
    def kubeconfig(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "kubeconfig", value)

    @_builtins.property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        The list of key value pairs representing additional
        properties of the cluster. Changing this creates a new cluster.
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "labels", value)

    @_builtins.property
    @pulumi.getter(name="masterAddresses")
    def master_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        return pulumi.get(self, "master_addresses")

    @master_addresses.setter
    def master_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "master_addresses", value)

    @_builtins.property
    @pulumi.getter(name="masterCount")
    def master_count(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of master nodes for the cluster.
        Changing this creates a new cluster.
        """
        return pulumi.get(self, "master_count")

    @master_count.setter
    def master_count(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "master_count", value)

    @_builtins.property
    @pulumi.getter(name="masterFlavor")
    def master_flavor(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The flavor for the master nodes. Can be set via
        the `OS_MAGNUM_MASTER_FLAVOR` environment variable. Changing this creates a
        new cluster.
        """
        return pulumi.get(self, "master_flavor")

    @master_flavor.setter
    def master_flavor(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "master_flavor", value)

    @_builtins.property
    @pulumi.getter(name="masterLbEnabled")
    def master_lb_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether to create a load balancer
        for the master nodes. Changing this creates a new cluster.
        """
        return pulumi.get(self, "master_lb_enabled")

    @master_lb_enabled.setter
    def master_lb_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "master_lb_enabled", value)

    @_builtins.property
    @pulumi.getter(name="mergeLabels")
    def merge_labels(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the provided labels should be
        merged with cluster template labels. Changing this creates a new cluster.
        """
        return pulumi.get(self, "merge_labels")

    @merge_labels.setter
    def merge_labels(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "merge_labels", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the cluster. Changing this creates a new
        cluster.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="nodeAddresses")
    def node_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        return pulumi.get(self, "node_addresses")

    @node_addresses.setter
    def node_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "node_addresses", value)

    @_builtins.property
    @pulumi.getter(name="nodeCount")
    def node_count(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of nodes for the cluster.
        """
        return pulumi.get(self, "node_count")

    @node_count.setter
    def node_count(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "node_count", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The project of the cluster. Required if admin wants
        to create a cluster in another project. Changing this creates a new
        cluster.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V1 Container Infra
        client. A Container Infra client is needed to create a cluster. If omitted,
        the `region` argument of the provider is used. Changing this creates a new
        cluster.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "stack_id")

    @stack_id.setter
    def stack_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "stack_id", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The user of the cluster. Required if admin wants to
        create a cluster template for another user. Changing this creates a new
        cluster.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_id", value)


@pulumi.type_token("openstack:containerinfra/cluster:Cluster")
class Cluster(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_template_id: Optional[pulumi.Input[_builtins.str]] = None,
                 create_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 discovery_url: Optional[pulumi.Input[_builtins.str]] = None,
                 docker_volume_size: Optional[pulumi.Input[_builtins.int]] = None,
                 fixed_network: Optional[pulumi.Input[_builtins.str]] = None,
                 fixed_subnet: Optional[pulumi.Input[_builtins.str]] = None,
                 flavor: Optional[pulumi.Input[_builtins.str]] = None,
                 floating_ip_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 keypair: Optional[pulumi.Input[_builtins.str]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 master_count: Optional[pulumi.Input[_builtins.int]] = None,
                 master_flavor: Optional[pulumi.Input[_builtins.str]] = None,
                 master_lb_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 merge_labels: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_count: Optional[pulumi.Input[_builtins.int]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a V1 Magnum cluster resource within OpenStack.

        > **Note:** All arguments including the `kubeconfig` computed attribute will be
        stored in the raw state as plain-text. Read more about sensitive data in
        state.

        ## Example Usage

        ### Create a Cluster

        ```python
        import pulumi
        import pulumi_openstack as openstack

        cluster1 = openstack.containerinfra.Cluster("cluster_1",
            name="cluster_1",
            cluster_template_id="b9a45c5c-cd03-4958-82aa-b80bf93cb922",
            master_count=3,
            node_count=5,
            keypair="ssh_keypair")
        ```

        ## Attributes reference

        The following attributes are exported:

        * `region` - See Argument Reference above.
        * `name` - See Argument Reference above.
        * `project_id` - See Argument Reference above.
        * `created_at` - The time at which cluster was created.
        * `updated_at` - The time at which cluster was created.
        * `api_address` - COE API address.
        * `coe_version` - COE software version.
        * `cluster_template_id` - See Argument Reference above.
        * `container_version` - Container software version.
        * `create_timeout` - See Argument Reference above.
        * `discovery_url` - See Argument Reference above.
        * `docker_volume_size` - See Argument Reference above.
        * `flavor` - See Argument Reference above.
        * `master_flavor` - See Argument Reference above.
        * `keypair` - See Argument Reference above.
        * `labels` - See Argument Reference above.
        * `merge_labels` - See Argument Reference above.
        * `master_count` - See Argument Reference above.
        * `node_count` - See Argument Reference above.
        * `fixed_network` - See Argument Reference above.
        * `fixed_subnet` - See Argument Reference above.
        * `floating_ip_enabled` - See Argument Reference above.
        * `master_addresses` - IP addresses of the master node of the cluster.
        * `node_addresses` - IP addresses of the node of the cluster.
        * `stack_id` - UUID of the Orchestration service stack.
        * `kubeconfig` - The Kubernetes cluster's credentials
          * `raw_config` - The raw kubeconfig file
          * `host` - The cluster's API server URL
          * `cluster_ca_certificate` - The cluster's CA certificate
          * `client_key` - The client's RSA key
          * `client_certificate` - The client's certificate

        ## Import

        Clusters can be imported using the `id`, e.g.

        ```sh
        $ pulumi import openstack:containerinfra/cluster:Cluster cluster_1 ce0f9463-dd25-474b-9fe8-94de63e5e42b
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cluster_template_id: The UUID of the V1 Container Infra cluster
               template. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.int] create_timeout: The timeout (in minutes) for creating the
               cluster. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] discovery_url: The URL used for cluster node discovery.
               Changing this creates a new cluster.
        :param pulumi.Input[_builtins.int] docker_volume_size: The size (in GB) of the Docker volume.
               Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] fixed_network: The fixed network that will be attached to the
               cluster. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] fixed_subnet: The fixed subnet that will be attached to the
               cluster. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] flavor: The flavor for the nodes of the cluster. Can be set via
               the `OS_MAGNUM_FLAVOR` environment variable. Changing this creates a new
               cluster.
        :param pulumi.Input[_builtins.bool] floating_ip_enabled: Indicates whether floating IP should be
               created for every cluster node. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] keypair: The name of the Compute service SSH keypair. Changing
               this creates a new cluster.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] labels: The list of key value pairs representing additional
               properties of the cluster. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.int] master_count: The number of master nodes for the cluster.
               Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] master_flavor: The flavor for the master nodes. Can be set via
               the `OS_MAGNUM_MASTER_FLAVOR` environment variable. Changing this creates a
               new cluster.
        :param pulumi.Input[_builtins.bool] master_lb_enabled: Indicates whether to create a load balancer
               for the master nodes. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.bool] merge_labels: Indicates whether the provided labels should be
               merged with cluster template labels. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] name: The name of the cluster. Changing this creates a new
               cluster.
        :param pulumi.Input[_builtins.int] node_count: The number of nodes for the cluster.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V1 Container Infra
               client. A Container Infra client is needed to create a cluster. If omitted,
               the `region` argument of the provider is used. Changing this creates a new
               cluster.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ClusterArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a V1 Magnum cluster resource within OpenStack.

        > **Note:** All arguments including the `kubeconfig` computed attribute will be
        stored in the raw state as plain-text. Read more about sensitive data in
        state.

        ## Example Usage

        ### Create a Cluster

        ```python
        import pulumi
        import pulumi_openstack as openstack

        cluster1 = openstack.containerinfra.Cluster("cluster_1",
            name="cluster_1",
            cluster_template_id="b9a45c5c-cd03-4958-82aa-b80bf93cb922",
            master_count=3,
            node_count=5,
            keypair="ssh_keypair")
        ```

        ## Attributes reference

        The following attributes are exported:

        * `region` - See Argument Reference above.
        * `name` - See Argument Reference above.
        * `project_id` - See Argument Reference above.
        * `created_at` - The time at which cluster was created.
        * `updated_at` - The time at which cluster was created.
        * `api_address` - COE API address.
        * `coe_version` - COE software version.
        * `cluster_template_id` - See Argument Reference above.
        * `container_version` - Container software version.
        * `create_timeout` - See Argument Reference above.
        * `discovery_url` - See Argument Reference above.
        * `docker_volume_size` - See Argument Reference above.
        * `flavor` - See Argument Reference above.
        * `master_flavor` - See Argument Reference above.
        * `keypair` - See Argument Reference above.
        * `labels` - See Argument Reference above.
        * `merge_labels` - See Argument Reference above.
        * `master_count` - See Argument Reference above.
        * `node_count` - See Argument Reference above.
        * `fixed_network` - See Argument Reference above.
        * `fixed_subnet` - See Argument Reference above.
        * `floating_ip_enabled` - See Argument Reference above.
        * `master_addresses` - IP addresses of the master node of the cluster.
        * `node_addresses` - IP addresses of the node of the cluster.
        * `stack_id` - UUID of the Orchestration service stack.
        * `kubeconfig` - The Kubernetes cluster's credentials
          * `raw_config` - The raw kubeconfig file
          * `host` - The cluster's API server URL
          * `cluster_ca_certificate` - The cluster's CA certificate
          * `client_key` - The client's RSA key
          * `client_certificate` - The client's certificate

        ## Import

        Clusters can be imported using the `id`, e.g.

        ```sh
        $ pulumi import openstack:containerinfra/cluster:Cluster cluster_1 ce0f9463-dd25-474b-9fe8-94de63e5e42b
        ```

        :param str resource_name: The name of the resource.
        :param ClusterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ClusterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_template_id: Optional[pulumi.Input[_builtins.str]] = None,
                 create_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 discovery_url: Optional[pulumi.Input[_builtins.str]] = None,
                 docker_volume_size: Optional[pulumi.Input[_builtins.int]] = None,
                 fixed_network: Optional[pulumi.Input[_builtins.str]] = None,
                 fixed_subnet: Optional[pulumi.Input[_builtins.str]] = None,
                 flavor: Optional[pulumi.Input[_builtins.str]] = None,
                 floating_ip_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 keypair: Optional[pulumi.Input[_builtins.str]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 master_count: Optional[pulumi.Input[_builtins.int]] = None,
                 master_flavor: Optional[pulumi.Input[_builtins.str]] = None,
                 master_lb_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 merge_labels: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_count: Optional[pulumi.Input[_builtins.int]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ClusterArgs.__new__(ClusterArgs)

            __props__.__dict__["cluster_template_id"] = cluster_template_id
            __props__.__dict__["create_timeout"] = create_timeout
            __props__.__dict__["discovery_url"] = discovery_url
            __props__.__dict__["docker_volume_size"] = docker_volume_size
            __props__.__dict__["fixed_network"] = fixed_network
            __props__.__dict__["fixed_subnet"] = fixed_subnet
            __props__.__dict__["flavor"] = flavor
            __props__.__dict__["floating_ip_enabled"] = floating_ip_enabled
            __props__.__dict__["keypair"] = keypair
            __props__.__dict__["labels"] = labels
            __props__.__dict__["master_count"] = master_count
            __props__.__dict__["master_flavor"] = master_flavor
            __props__.__dict__["master_lb_enabled"] = master_lb_enabled
            __props__.__dict__["merge_labels"] = merge_labels
            __props__.__dict__["name"] = name
            __props__.__dict__["node_count"] = node_count
            __props__.__dict__["region"] = region
            __props__.__dict__["api_address"] = None
            __props__.__dict__["coe_version"] = None
            __props__.__dict__["container_version"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["kubeconfig"] = None
            __props__.__dict__["master_addresses"] = None
            __props__.__dict__["node_addresses"] = None
            __props__.__dict__["project_id"] = None
            __props__.__dict__["stack_id"] = None
            __props__.__dict__["updated_at"] = None
            __props__.__dict__["user_id"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["kubeconfig"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Cluster, __self__).__init__(
            'openstack:containerinfra/cluster:Cluster',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            api_address: Optional[pulumi.Input[_builtins.str]] = None,
            cluster_template_id: Optional[pulumi.Input[_builtins.str]] = None,
            coe_version: Optional[pulumi.Input[_builtins.str]] = None,
            container_version: Optional[pulumi.Input[_builtins.str]] = None,
            create_timeout: Optional[pulumi.Input[_builtins.int]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            discovery_url: Optional[pulumi.Input[_builtins.str]] = None,
            docker_volume_size: Optional[pulumi.Input[_builtins.int]] = None,
            fixed_network: Optional[pulumi.Input[_builtins.str]] = None,
            fixed_subnet: Optional[pulumi.Input[_builtins.str]] = None,
            flavor: Optional[pulumi.Input[_builtins.str]] = None,
            floating_ip_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            keypair: Optional[pulumi.Input[_builtins.str]] = None,
            kubeconfig: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            master_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            master_count: Optional[pulumi.Input[_builtins.int]] = None,
            master_flavor: Optional[pulumi.Input[_builtins.str]] = None,
            master_lb_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            merge_labels: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            node_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            node_count: Optional[pulumi.Input[_builtins.int]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            stack_id: Optional[pulumi.Input[_builtins.str]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None,
            user_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'Cluster':
        """
        Get an existing Cluster resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cluster_template_id: The UUID of the V1 Container Infra cluster
               template. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.int] create_timeout: The timeout (in minutes) for creating the
               cluster. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] discovery_url: The URL used for cluster node discovery.
               Changing this creates a new cluster.
        :param pulumi.Input[_builtins.int] docker_volume_size: The size (in GB) of the Docker volume.
               Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] fixed_network: The fixed network that will be attached to the
               cluster. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] fixed_subnet: The fixed subnet that will be attached to the
               cluster. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] flavor: The flavor for the nodes of the cluster. Can be set via
               the `OS_MAGNUM_FLAVOR` environment variable. Changing this creates a new
               cluster.
        :param pulumi.Input[_builtins.bool] floating_ip_enabled: Indicates whether floating IP should be
               created for every cluster node. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] keypair: The name of the Compute service SSH keypair. Changing
               this creates a new cluster.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] labels: The list of key value pairs representing additional
               properties of the cluster. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.int] master_count: The number of master nodes for the cluster.
               Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] master_flavor: The flavor for the master nodes. Can be set via
               the `OS_MAGNUM_MASTER_FLAVOR` environment variable. Changing this creates a
               new cluster.
        :param pulumi.Input[_builtins.bool] master_lb_enabled: Indicates whether to create a load balancer
               for the master nodes. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.bool] merge_labels: Indicates whether the provided labels should be
               merged with cluster template labels. Changing this creates a new cluster.
        :param pulumi.Input[_builtins.str] name: The name of the cluster. Changing this creates a new
               cluster.
        :param pulumi.Input[_builtins.int] node_count: The number of nodes for the cluster.
        :param pulumi.Input[_builtins.str] project_id: The project of the cluster. Required if admin wants
               to create a cluster in another project. Changing this creates a new
               cluster.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V1 Container Infra
               client. A Container Infra client is needed to create a cluster. If omitted,
               the `region` argument of the provider is used. Changing this creates a new
               cluster.
        :param pulumi.Input[_builtins.str] user_id: The user of the cluster. Required if admin wants to
               create a cluster template for another user. Changing this creates a new
               cluster.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ClusterState.__new__(_ClusterState)

        __props__.__dict__["api_address"] = api_address
        __props__.__dict__["cluster_template_id"] = cluster_template_id
        __props__.__dict__["coe_version"] = coe_version
        __props__.__dict__["container_version"] = container_version
        __props__.__dict__["create_timeout"] = create_timeout
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["discovery_url"] = discovery_url
        __props__.__dict__["docker_volume_size"] = docker_volume_size
        __props__.__dict__["fixed_network"] = fixed_network
        __props__.__dict__["fixed_subnet"] = fixed_subnet
        __props__.__dict__["flavor"] = flavor
        __props__.__dict__["floating_ip_enabled"] = floating_ip_enabled
        __props__.__dict__["keypair"] = keypair
        __props__.__dict__["kubeconfig"] = kubeconfig
        __props__.__dict__["labels"] = labels
        __props__.__dict__["master_addresses"] = master_addresses
        __props__.__dict__["master_count"] = master_count
        __props__.__dict__["master_flavor"] = master_flavor
        __props__.__dict__["master_lb_enabled"] = master_lb_enabled
        __props__.__dict__["merge_labels"] = merge_labels
        __props__.__dict__["name"] = name
        __props__.__dict__["node_addresses"] = node_addresses
        __props__.__dict__["node_count"] = node_count
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["region"] = region
        __props__.__dict__["stack_id"] = stack_id
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["user_id"] = user_id
        return Cluster(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="apiAddress")
    def api_address(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "api_address")

    @_builtins.property
    @pulumi.getter(name="clusterTemplateId")
    def cluster_template_id(self) -> pulumi.Output[_builtins.str]:
        """
        The UUID of the V1 Container Infra cluster
        template. Changing this creates a new cluster.
        """
        return pulumi.get(self, "cluster_template_id")

    @_builtins.property
    @pulumi.getter(name="coeVersion")
    def coe_version(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "coe_version")

    @_builtins.property
    @pulumi.getter(name="containerVersion")
    def container_version(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "container_version")

    @_builtins.property
    @pulumi.getter(name="createTimeout")
    def create_timeout(self) -> pulumi.Output[_builtins.int]:
        """
        The timeout (in minutes) for creating the
        cluster. Changing this creates a new cluster.
        """
        return pulumi.get(self, "create_timeout")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="discoveryUrl")
    def discovery_url(self) -> pulumi.Output[_builtins.str]:
        """
        The URL used for cluster node discovery.
        Changing this creates a new cluster.
        """
        return pulumi.get(self, "discovery_url")

    @_builtins.property
    @pulumi.getter(name="dockerVolumeSize")
    def docker_volume_size(self) -> pulumi.Output[_builtins.int]:
        """
        The size (in GB) of the Docker volume.
        Changing this creates a new cluster.
        """
        return pulumi.get(self, "docker_volume_size")

    @_builtins.property
    @pulumi.getter(name="fixedNetwork")
    def fixed_network(self) -> pulumi.Output[_builtins.str]:
        """
        The fixed network that will be attached to the
        cluster. Changing this creates a new cluster.
        """
        return pulumi.get(self, "fixed_network")

    @_builtins.property
    @pulumi.getter(name="fixedSubnet")
    def fixed_subnet(self) -> pulumi.Output[_builtins.str]:
        """
        The fixed subnet that will be attached to the
        cluster. Changing this creates a new cluster.
        """
        return pulumi.get(self, "fixed_subnet")

    @_builtins.property
    @pulumi.getter
    def flavor(self) -> pulumi.Output[_builtins.str]:
        """
        The flavor for the nodes of the cluster. Can be set via
        the `OS_MAGNUM_FLAVOR` environment variable. Changing this creates a new
        cluster.
        """
        return pulumi.get(self, "flavor")

    @_builtins.property
    @pulumi.getter(name="floatingIpEnabled")
    def floating_ip_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether floating IP should be
        created for every cluster node. Changing this creates a new cluster.
        """
        return pulumi.get(self, "floating_ip_enabled")

    @_builtins.property
    @pulumi.getter
    def keypair(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the Compute service SSH keypair. Changing
        this creates a new cluster.
        """
        return pulumi.get(self, "keypair")

    @_builtins.property
    @pulumi.getter
    def kubeconfig(self) -> pulumi.Output[Mapping[str, _builtins.str]]:
        return pulumi.get(self, "kubeconfig")

    @_builtins.property
    @pulumi.getter
    def labels(self) -> pulumi.Output[Mapping[str, _builtins.str]]:
        """
        The list of key value pairs representing additional
        properties of the cluster. Changing this creates a new cluster.
        """
        return pulumi.get(self, "labels")

    @_builtins.property
    @pulumi.getter(name="masterAddresses")
    def master_addresses(self) -> pulumi.Output[Sequence[_builtins.str]]:
        return pulumi.get(self, "master_addresses")

    @_builtins.property
    @pulumi.getter(name="masterCount")
    def master_count(self) -> pulumi.Output[_builtins.int]:
        """
        The number of master nodes for the cluster.
        Changing this creates a new cluster.
        """
        return pulumi.get(self, "master_count")

    @_builtins.property
    @pulumi.getter(name="masterFlavor")
    def master_flavor(self) -> pulumi.Output[_builtins.str]:
        """
        The flavor for the master nodes. Can be set via
        the `OS_MAGNUM_MASTER_FLAVOR` environment variable. Changing this creates a
        new cluster.
        """
        return pulumi.get(self, "master_flavor")

    @_builtins.property
    @pulumi.getter(name="masterLbEnabled")
    def master_lb_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates whether to create a load balancer
        for the master nodes. Changing this creates a new cluster.
        """
        return pulumi.get(self, "master_lb_enabled")

    @_builtins.property
    @pulumi.getter(name="mergeLabels")
    def merge_labels(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Indicates whether the provided labels should be
        merged with cluster template labels. Changing this creates a new cluster.
        """
        return pulumi.get(self, "merge_labels")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the cluster. Changing this creates a new
        cluster.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="nodeAddresses")
    def node_addresses(self) -> pulumi.Output[Sequence[_builtins.str]]:
        return pulumi.get(self, "node_addresses")

    @_builtins.property
    @pulumi.getter(name="nodeCount")
    def node_count(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The number of nodes for the cluster.
        """
        return pulumi.get(self, "node_count")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        The project of the cluster. Required if admin wants
        to create a cluster in another project. Changing this creates a new
        cluster.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region in which to obtain the V1 Container Infra
        client. A Container Infra client is needed to create a cluster. If omitted,
        the `region` argument of the provider is used. Changing this creates a new
        cluster.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "stack_id")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[_builtins.str]:
        """
        The user of the cluster. Required if admin wants to
        create a cluster template for another user. Changing this creates a new
        cluster.
        """
        return pulumi.get(self, "user_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['QuoteSetV3Args', 'QuoteSetV3']

@pulumi.input_type
class QuoteSetV3Args:
    def __init__(__self__, *,
                 project_id: pulumi.Input[_builtins.str],
                 backup_gigabytes: Optional[pulumi.Input[_builtins.int]] = None,
                 backups: Optional[pulumi.Input[_builtins.int]] = None,
                 gigabytes: Optional[pulumi.Input[_builtins.int]] = None,
                 groups: Optional[pulumi.Input[_builtins.int]] = None,
                 per_volume_gigabytes: Optional[pulumi.Input[_builtins.int]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 snapshots: Optional[pulumi.Input[_builtins.int]] = None,
                 volume_type_quota: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 volumes: Optional[pulumi.Input[_builtins.int]] = None):
        """
        The set of arguments for constructing a QuoteSetV3 resource.
        :param pulumi.Input[_builtins.str] project_id: ID of the project to manage quotas. Changing this
               creates a new quotaset.
        :param pulumi.Input[_builtins.int] backup_gigabytes: Quota value for backup gigabytes. Changing
               this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] backups: Quota value for backups. Changing this updates the
               existing quotaset.
        :param pulumi.Input[_builtins.int] gigabytes: Quota value for gigabytes. Changing this updates the
               existing quotaset.
        :param pulumi.Input[_builtins.int] groups: Quota value for groups. Changing this updates the
               existing quotaset.
        :param pulumi.Input[_builtins.int] per_volume_gigabytes: Quota value for gigabytes per volume .
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.str] region: The region in which to create the volume. If
               omitted, the `region` argument of the provider is used. Changing this
               creates a new quotaset.
        :param pulumi.Input[_builtins.int] snapshots: Quota value for snapshots. Changing this updates the
               existing quotaset.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] volume_type_quota: Key/Value pairs for setting quota for
               volumes types. Possible keys are `snapshots_<volume_type_name>`,
               `volumes_<volume_type_name>` and `gigabytes_<volume_type_name>`.
        :param pulumi.Input[_builtins.int] volumes: Quota value for volumes. Changing this updates the
               existing quotaset.
        """
        pulumi.set(__self__, "project_id", project_id)
        if backup_gigabytes is not None:
            pulumi.set(__self__, "backup_gigabytes", backup_gigabytes)
        if backups is not None:
            pulumi.set(__self__, "backups", backups)
        if gigabytes is not None:
            pulumi.set(__self__, "gigabytes", gigabytes)
        if groups is not None:
            pulumi.set(__self__, "groups", groups)
        if per_volume_gigabytes is not None:
            pulumi.set(__self__, "per_volume_gigabytes", per_volume_gigabytes)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if snapshots is not None:
            pulumi.set(__self__, "snapshots", snapshots)
        if volume_type_quota is not None:
            pulumi.set(__self__, "volume_type_quota", volume_type_quota)
        if volumes is not None:
            pulumi.set(__self__, "volumes", volumes)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the project to manage quotas. Changing this
        creates a new quotaset.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="backupGigabytes")
    def backup_gigabytes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for backup gigabytes. Changing
        this updates the existing quotaset.
        """
        return pulumi.get(self, "backup_gigabytes")

    @backup_gigabytes.setter
    def backup_gigabytes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "backup_gigabytes", value)

    @_builtins.property
    @pulumi.getter
    def backups(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for backups. Changing this updates the
        existing quotaset.
        """
        return pulumi.get(self, "backups")

    @backups.setter
    def backups(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "backups", value)

    @_builtins.property
    @pulumi.getter
    def gigabytes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for gigabytes. Changing this updates the
        existing quotaset.
        """
        return pulumi.get(self, "gigabytes")

    @gigabytes.setter
    def gigabytes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "gigabytes", value)

    @_builtins.property
    @pulumi.getter
    def groups(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for groups. Changing this updates the
        existing quotaset.
        """
        return pulumi.get(self, "groups")

    @groups.setter
    def groups(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "groups", value)

    @_builtins.property
    @pulumi.getter(name="perVolumeGigabytes")
    def per_volume_gigabytes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for gigabytes per volume .
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "per_volume_gigabytes")

    @per_volume_gigabytes.setter
    def per_volume_gigabytes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "per_volume_gigabytes", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to create the volume. If
        omitted, the `region` argument of the provider is used. Changing this
        creates a new quotaset.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def snapshots(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for snapshots. Changing this updates the
        existing quotaset.
        """
        return pulumi.get(self, "snapshots")

    @snapshots.setter
    def snapshots(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "snapshots", value)

    @_builtins.property
    @pulumi.getter(name="volumeTypeQuota")
    def volume_type_quota(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Key/Value pairs for setting quota for
        volumes types. Possible keys are `snapshots_<volume_type_name>`,
        `volumes_<volume_type_name>` and `gigabytes_<volume_type_name>`.
        """
        return pulumi.get(self, "volume_type_quota")

    @volume_type_quota.setter
    def volume_type_quota(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "volume_type_quota", value)

    @_builtins.property
    @pulumi.getter
    def volumes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for volumes. Changing this updates the
        existing quotaset.
        """
        return pulumi.get(self, "volumes")

    @volumes.setter
    def volumes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "volumes", value)


@pulumi.input_type
class _QuoteSetV3State:
    def __init__(__self__, *,
                 backup_gigabytes: Optional[pulumi.Input[_builtins.int]] = None,
                 backups: Optional[pulumi.Input[_builtins.int]] = None,
                 gigabytes: Optional[pulumi.Input[_builtins.int]] = None,
                 groups: Optional[pulumi.Input[_builtins.int]] = None,
                 per_volume_gigabytes: Optional[pulumi.Input[_builtins.int]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 snapshots: Optional[pulumi.Input[_builtins.int]] = None,
                 volume_type_quota: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 volumes: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering QuoteSetV3 resources.
        :param pulumi.Input[_builtins.int] backup_gigabytes: Quota value for backup gigabytes. Changing
               this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] backups: Quota value for backups. Changing this updates the
               existing quotaset.
        :param pulumi.Input[_builtins.int] gigabytes: Quota value for gigabytes. Changing this updates the
               existing quotaset.
        :param pulumi.Input[_builtins.int] groups: Quota value for groups. Changing this updates the
               existing quotaset.
        :param pulumi.Input[_builtins.int] per_volume_gigabytes: Quota value for gigabytes per volume .
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.str] project_id: ID of the project to manage quotas. Changing this
               creates a new quotaset.
        :param pulumi.Input[_builtins.str] region: The region in which to create the volume. If
               omitted, the `region` argument of the provider is used. Changing this
               creates a new quotaset.
        :param pulumi.Input[_builtins.int] snapshots: Quota value for snapshots. Changing this updates the
               existing quotaset.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] volume_type_quota: Key/Value pairs for setting quota for
               volumes types. Possible keys are `snapshots_<volume_type_name>`,
               `volumes_<volume_type_name>` and `gigabytes_<volume_type_name>`.
        :param pulumi.Input[_builtins.int] volumes: Quota value for volumes. Changing this updates the
               existing quotaset.
        """
        if backup_gigabytes is not None:
            pulumi.set(__self__, "backup_gigabytes", backup_gigabytes)
        if backups is not None:
            pulumi.set(__self__, "backups", backups)
        if gigabytes is not None:
            pulumi.set(__self__, "gigabytes", gigabytes)
        if groups is not None:
            pulumi.set(__self__, "groups", groups)
        if per_volume_gigabytes is not None:
            pulumi.set(__self__, "per_volume_gigabytes", per_volume_gigabytes)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if snapshots is not None:
            pulumi.set(__self__, "snapshots", snapshots)
        if volume_type_quota is not None:
            pulumi.set(__self__, "volume_type_quota", volume_type_quota)
        if volumes is not None:
            pulumi.set(__self__, "volumes", volumes)

    @_builtins.property
    @pulumi.getter(name="backupGigabytes")
    def backup_gigabytes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for backup gigabytes. Changing
        this updates the existing quotaset.
        """
        return pulumi.get(self, "backup_gigabytes")

    @backup_gigabytes.setter
    def backup_gigabytes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "backup_gigabytes", value)

    @_builtins.property
    @pulumi.getter
    def backups(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for backups. Changing this updates the
        existing quotaset.
        """
        return pulumi.get(self, "backups")

    @backups.setter
    def backups(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "backups", value)

    @_builtins.property
    @pulumi.getter
    def gigabytes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for gigabytes. Changing this updates the
        existing quotaset.
        """
        return pulumi.get(self, "gigabytes")

    @gigabytes.setter
    def gigabytes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "gigabytes", value)

    @_builtins.property
    @pulumi.getter
    def groups(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for groups. Changing this updates the
        existing quotaset.
        """
        return pulumi.get(self, "groups")

    @groups.setter
    def groups(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "groups", value)

    @_builtins.property
    @pulumi.getter(name="perVolumeGigabytes")
    def per_volume_gigabytes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for gigabytes per volume .
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "per_volume_gigabytes")

    @per_volume_gigabytes.setter
    def per_volume_gigabytes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "per_volume_gigabytes", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the project to manage quotas. Changing this
        creates a new quotaset.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to create the volume. If
        omitted, the `region` argument of the provider is used. Changing this
        creates a new quotaset.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def snapshots(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for snapshots. Changing this updates the
        existing quotaset.
        """
        return pulumi.get(self, "snapshots")

    @snapshots.setter
    def snapshots(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "snapshots", value)

    @_builtins.property
    @pulumi.getter(name="volumeTypeQuota")
    def volume_type_quota(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Key/Value pairs for setting quota for
        volumes types. Possible keys are `snapshots_<volume_type_name>`,
        `volumes_<volume_type_name>` and `gigabytes_<volume_type_name>`.
        """
        return pulumi.get(self, "volume_type_quota")

    @volume_type_quota.setter
    def volume_type_quota(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "volume_type_quota", value)

    @_builtins.property
    @pulumi.getter
    def volumes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for volumes. Changing this updates the
        existing quotaset.
        """
        return pulumi.get(self, "volumes")

    @volumes.setter
    def volumes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "volumes", value)


@pulumi.type_token("openstack:blockstorage/quoteSetV3:QuoteSetV3")
class QuoteSetV3(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backup_gigabytes: Optional[pulumi.Input[_builtins.int]] = None,
                 backups: Optional[pulumi.Input[_builtins.int]] = None,
                 gigabytes: Optional[pulumi.Input[_builtins.int]] = None,
                 groups: Optional[pulumi.Input[_builtins.int]] = None,
                 per_volume_gigabytes: Optional[pulumi.Input[_builtins.int]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 snapshots: Optional[pulumi.Input[_builtins.int]] = None,
                 volume_type_quota: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 volumes: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        Manages a V3 block storage quotaset resource within OpenStack.

        > **Note:** This usually requires admin privileges.

        > **Note:** This resource has a no-op deletion so no actual actions will be done against the OpenStack API
            in case of delete call.

        ## Import

        Quotasets can be imported using the `project_id/region`, e.g.

        ```sh
        $ pulumi import openstack:blockstorage/quoteSetV3:QuoteSetV3 quotaset_1 2a0f2240-c5e6-41de-896d-e80d97428d6b/region_1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] backup_gigabytes: Quota value for backup gigabytes. Changing
               this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] backups: Quota value for backups. Changing this updates the
               existing quotaset.
        :param pulumi.Input[_builtins.int] gigabytes: Quota value for gigabytes. Changing this updates the
               existing quotaset.
        :param pulumi.Input[_builtins.int] groups: Quota value for groups. Changing this updates the
               existing quotaset.
        :param pulumi.Input[_builtins.int] per_volume_gigabytes: Quota value for gigabytes per volume .
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.str] project_id: ID of the project to manage quotas. Changing this
               creates a new quotaset.
        :param pulumi.Input[_builtins.str] region: The region in which to create the volume. If
               omitted, the `region` argument of the provider is used. Changing this
               creates a new quotaset.
        :param pulumi.Input[_builtins.int] snapshots: Quota value for snapshots. Changing this updates the
               existing quotaset.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] volume_type_quota: Key/Value pairs for setting quota for
               volumes types. Possible keys are `snapshots_<volume_type_name>`,
               `volumes_<volume_type_name>` and `gigabytes_<volume_type_name>`.
        :param pulumi.Input[_builtins.int] volumes: Quota value for volumes. Changing this updates the
               existing quotaset.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: QuoteSetV3Args,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a V3 block storage quotaset resource within OpenStack.

        > **Note:** This usually requires admin privileges.

        > **Note:** This resource has a no-op deletion so no actual actions will be done against the OpenStack API
            in case of delete call.

        ## Import

        Quotasets can be imported using the `project_id/region`, e.g.

        ```sh
        $ pulumi import openstack:blockstorage/quoteSetV3:QuoteSetV3 quotaset_1 2a0f2240-c5e6-41de-896d-e80d97428d6b/region_1
        ```

        :param str resource_name: The name of the resource.
        :param QuoteSetV3Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(QuoteSetV3Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backup_gigabytes: Optional[pulumi.Input[_builtins.int]] = None,
                 backups: Optional[pulumi.Input[_builtins.int]] = None,
                 gigabytes: Optional[pulumi.Input[_builtins.int]] = None,
                 groups: Optional[pulumi.Input[_builtins.int]] = None,
                 per_volume_gigabytes: Optional[pulumi.Input[_builtins.int]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 snapshots: Optional[pulumi.Input[_builtins.int]] = None,
                 volume_type_quota: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 volumes: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = QuoteSetV3Args.__new__(QuoteSetV3Args)

            __props__.__dict__["backup_gigabytes"] = backup_gigabytes
            __props__.__dict__["backups"] = backups
            __props__.__dict__["gigabytes"] = gigabytes
            __props__.__dict__["groups"] = groups
            __props__.__dict__["per_volume_gigabytes"] = per_volume_gigabytes
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["region"] = region
            __props__.__dict__["snapshots"] = snapshots
            __props__.__dict__["volume_type_quota"] = volume_type_quota
            __props__.__dict__["volumes"] = volumes
        super(QuoteSetV3, __self__).__init__(
            'openstack:blockstorage/quoteSetV3:QuoteSetV3',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            backup_gigabytes: Optional[pulumi.Input[_builtins.int]] = None,
            backups: Optional[pulumi.Input[_builtins.int]] = None,
            gigabytes: Optional[pulumi.Input[_builtins.int]] = None,
            groups: Optional[pulumi.Input[_builtins.int]] = None,
            per_volume_gigabytes: Optional[pulumi.Input[_builtins.int]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            snapshots: Optional[pulumi.Input[_builtins.int]] = None,
            volume_type_quota: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            volumes: Optional[pulumi.Input[_builtins.int]] = None) -> 'QuoteSetV3':
        """
        Get an existing QuoteSetV3 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] backup_gigabytes: Quota value for backup gigabytes. Changing
               this updates the existing quotaset.
        :param pulumi.Input[_builtins.int] backups: Quota value for backups. Changing this updates the
               existing quotaset.
        :param pulumi.Input[_builtins.int] gigabytes: Quota value for gigabytes. Changing this updates the
               existing quotaset.
        :param pulumi.Input[_builtins.int] groups: Quota value for groups. Changing this updates the
               existing quotaset.
        :param pulumi.Input[_builtins.int] per_volume_gigabytes: Quota value for gigabytes per volume .
               Changing this updates the existing quotaset.
        :param pulumi.Input[_builtins.str] project_id: ID of the project to manage quotas. Changing this
               creates a new quotaset.
        :param pulumi.Input[_builtins.str] region: The region in which to create the volume. If
               omitted, the `region` argument of the provider is used. Changing this
               creates a new quotaset.
        :param pulumi.Input[_builtins.int] snapshots: Quota value for snapshots. Changing this updates the
               existing quotaset.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] volume_type_quota: Key/Value pairs for setting quota for
               volumes types. Possible keys are `snapshots_<volume_type_name>`,
               `volumes_<volume_type_name>` and `gigabytes_<volume_type_name>`.
        :param pulumi.Input[_builtins.int] volumes: Quota value for volumes. Changing this updates the
               existing quotaset.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _QuoteSetV3State.__new__(_QuoteSetV3State)

        __props__.__dict__["backup_gigabytes"] = backup_gigabytes
        __props__.__dict__["backups"] = backups
        __props__.__dict__["gigabytes"] = gigabytes
        __props__.__dict__["groups"] = groups
        __props__.__dict__["per_volume_gigabytes"] = per_volume_gigabytes
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["region"] = region
        __props__.__dict__["snapshots"] = snapshots
        __props__.__dict__["volume_type_quota"] = volume_type_quota
        __props__.__dict__["volumes"] = volumes
        return QuoteSetV3(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="backupGigabytes")
    def backup_gigabytes(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for backup gigabytes. Changing
        this updates the existing quotaset.
        """
        return pulumi.get(self, "backup_gigabytes")

    @_builtins.property
    @pulumi.getter
    def backups(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for backups. Changing this updates the
        existing quotaset.
        """
        return pulumi.get(self, "backups")

    @_builtins.property
    @pulumi.getter
    def gigabytes(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for gigabytes. Changing this updates the
        existing quotaset.
        """
        return pulumi.get(self, "gigabytes")

    @_builtins.property
    @pulumi.getter
    def groups(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for groups. Changing this updates the
        existing quotaset.
        """
        return pulumi.get(self, "groups")

    @_builtins.property
    @pulumi.getter(name="perVolumeGigabytes")
    def per_volume_gigabytes(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for gigabytes per volume .
        Changing this updates the existing quotaset.
        """
        return pulumi.get(self, "per_volume_gigabytes")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the project to manage quotas. Changing this
        creates a new quotaset.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region in which to create the volume. If
        omitted, the `region` argument of the provider is used. Changing this
        creates a new quotaset.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def snapshots(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for snapshots. Changing this updates the
        existing quotaset.
        """
        return pulumi.get(self, "snapshots")

    @_builtins.property
    @pulumi.getter(name="volumeTypeQuota")
    def volume_type_quota(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        Key/Value pairs for setting quota for
        volumes types. Possible keys are `snapshots_<volume_type_name>`,
        `volumes_<volume_type_name>` and `gigabytes_<volume_type_name>`.
        """
        return pulumi.get(self, "volume_type_quota")

    @_builtins.property
    @pulumi.getter
    def volumes(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for volumes. Changing this updates the
        existing quotaset.
        """
        return pulumi.get(self, "volumes")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetSegmentV2Result',
    'AwaitableGetSegmentV2Result',
    'get_segment_v2',
    'get_segment_v2_output',
]

@pulumi.output_type
class GetSegmentV2Result:
    """
    A collection of values returned by getSegmentV2.
    """
    def __init__(__self__, created_at=None, description=None, id=None, name=None, network_id=None, network_type=None, physical_network=None, region=None, revision_number=None, segment_id=None, segmentation_id=None, updated_at=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if network_id and not isinstance(network_id, str):
            raise TypeError("Expected argument 'network_id' to be a str")
        pulumi.set(__self__, "network_id", network_id)
        if network_type and not isinstance(network_type, str):
            raise TypeError("Expected argument 'network_type' to be a str")
        pulumi.set(__self__, "network_type", network_type)
        if physical_network and not isinstance(physical_network, str):
            raise TypeError("Expected argument 'physical_network' to be a str")
        pulumi.set(__self__, "physical_network", physical_network)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if revision_number and not isinstance(revision_number, int):
            raise TypeError("Expected argument 'revision_number' to be a int")
        pulumi.set(__self__, "revision_number", revision_number)
        if segment_id and not isinstance(segment_id, str):
            raise TypeError("Expected argument 'segment_id' to be a str")
        pulumi.set(__self__, "segment_id", segment_id)
        if segmentation_id and not isinstance(segmentation_id, int):
            raise TypeError("Expected argument 'segmentation_id' to be a int")
        pulumi.set(__self__, "segmentation_id", segmentation_id)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        The date and time when the network segment was created.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="networkId")
    def network_id(self) -> _builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "network_id")

    @_builtins.property
    @pulumi.getter(name="networkType")
    def network_type(self) -> _builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "network_type")

    @_builtins.property
    @pulumi.getter(name="physicalNetwork")
    def physical_network(self) -> _builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "physical_network")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="revisionNumber")
    def revision_number(self) -> _builtins.int:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "revision_number")

    @_builtins.property
    @pulumi.getter(name="segmentId")
    def segment_id(self) -> _builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "segment_id")

    @_builtins.property
    @pulumi.getter(name="segmentationId")
    def segmentation_id(self) -> _builtins.int:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "segmentation_id")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        """
        The date and time when the network segment was last updated.
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetSegmentV2Result(GetSegmentV2Result):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSegmentV2Result(
            created_at=self.created_at,
            description=self.description,
            id=self.id,
            name=self.name,
            network_id=self.network_id,
            network_type=self.network_type,
            physical_network=self.physical_network,
            region=self.region,
            revision_number=self.revision_number,
            segment_id=self.segment_id,
            segmentation_id=self.segmentation_id,
            updated_at=self.updated_at)


def get_segment_v2(description: Optional[_builtins.str] = None,
                   name: Optional[_builtins.str] = None,
                   network_id: Optional[_builtins.str] = None,
                   network_type: Optional[_builtins.str] = None,
                   physical_network: Optional[_builtins.str] = None,
                   region: Optional[_builtins.str] = None,
                   revision_number: Optional[_builtins.int] = None,
                   segment_id: Optional[_builtins.str] = None,
                   segmentation_id: Optional[_builtins.int] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSegmentV2Result:
    """
    Use this data source to get the ID of an available OpenStack network.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_openstack as openstack

    network = openstack.networking.get_segment_v2(name="tf_test_segment")
    ```


    :param _builtins.str description: Human-readable description of the network segment.
    :param _builtins.str name: The name of the network segment.
    :param _builtins.str network_id: The ID of the network.
    :param _builtins.str network_type: The type of the network, such as `vlan`, `vxlan`,
           `flat`, `gre`, `geneve`, or `local`.
    :param _builtins.str physical_network: The name of the physical network.
    :param _builtins.str region: The region in which to obtain the V2 Neutron client.
           A Neutron client is needed to retrieve networks ids. If omitted, the
           `region` argument of the provider is used.
    :param _builtins.int revision_number: See Argument Reference above.
    :param _builtins.str segment_id: The ID of the network segment
    :param _builtins.int segmentation_id: The segmentation ID of the network segment.
    """
    __args__ = dict()
    __args__['description'] = description
    __args__['name'] = name
    __args__['networkId'] = network_id
    __args__['networkType'] = network_type
    __args__['physicalNetwork'] = physical_network
    __args__['region'] = region
    __args__['revisionNumber'] = revision_number
    __args__['segmentId'] = segment_id
    __args__['segmentationId'] = segmentation_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('openstack:networking/getSegmentV2:getSegmentV2', __args__, opts=opts, typ=GetSegmentV2Result).value

    return AwaitableGetSegmentV2Result(
        created_at=pulumi.get(__ret__, 'created_at'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        network_id=pulumi.get(__ret__, 'network_id'),
        network_type=pulumi.get(__ret__, 'network_type'),
        physical_network=pulumi.get(__ret__, 'physical_network'),
        region=pulumi.get(__ret__, 'region'),
        revision_number=pulumi.get(__ret__, 'revision_number'),
        segment_id=pulumi.get(__ret__, 'segment_id'),
        segmentation_id=pulumi.get(__ret__, 'segmentation_id'),
        updated_at=pulumi.get(__ret__, 'updated_at'))
def get_segment_v2_output(description: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          network_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          network_type: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          physical_network: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          revision_number: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                          segment_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          segmentation_id: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSegmentV2Result]:
    """
    Use this data source to get the ID of an available OpenStack network.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_openstack as openstack

    network = openstack.networking.get_segment_v2(name="tf_test_segment")
    ```


    :param _builtins.str description: Human-readable description of the network segment.
    :param _builtins.str name: The name of the network segment.
    :param _builtins.str network_id: The ID of the network.
    :param _builtins.str network_type: The type of the network, such as `vlan`, `vxlan`,
           `flat`, `gre`, `geneve`, or `local`.
    :param _builtins.str physical_network: The name of the physical network.
    :param _builtins.str region: The region in which to obtain the V2 Neutron client.
           A Neutron client is needed to retrieve networks ids. If omitted, the
           `region` argument of the provider is used.
    :param _builtins.int revision_number: See Argument Reference above.
    :param _builtins.str segment_id: The ID of the network segment
    :param _builtins.int segmentation_id: The segmentation ID of the network segment.
    """
    __args__ = dict()
    __args__['description'] = description
    __args__['name'] = name
    __args__['networkId'] = network_id
    __args__['networkType'] = network_type
    __args__['physicalNetwork'] = physical_network
    __args__['region'] = region
    __args__['revisionNumber'] = revision_number
    __args__['segmentId'] = segment_id
    __args__['segmentationId'] = segmentation_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('openstack:networking/getSegmentV2:getSegmentV2', __args__, opts=opts, typ=GetSegmentV2Result)
    return __ret__.apply(lambda __response__: GetSegmentV2Result(
        created_at=pulumi.get(__response__, 'created_at'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        network_id=pulumi.get(__response__, 'network_id'),
        network_type=pulumi.get(__response__, 'network_type'),
        physical_network=pulumi.get(__response__, 'physical_network'),
        region=pulumi.get(__response__, 'region'),
        revision_number=pulumi.get(__response__, 'revision_number'),
        segment_id=pulumi.get(__response__, 'segment_id'),
        segmentation_id=pulumi.get(__response__, 'segmentation_id'),
        updated_at=pulumi.get(__response__, 'updated_at')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['TaasTapMirrorV2Args', 'TaasTapMirrorV2']

@pulumi.input_type
class TaasTapMirrorV2Args:
    def __init__(__self__, *,
                 directions: pulumi.Input['TaasTapMirrorV2DirectionsArgs'],
                 mirror_type: pulumi.Input[_builtins.str],
                 port_id: pulumi.Input[_builtins.str],
                 remote_ip: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a TaasTapMirrorV2 resource.
        :param pulumi.Input['TaasTapMirrorV2DirectionsArgs'] directions: A block declaring the directions to be mirrored and their
               identifiers. One block has to be declared with at least one direction. Changing
               this creates a new Tap Mirror.
        :param pulumi.Input[_builtins.str] mirror_type: The type of the mirroring, can be `gre` or `erspanv1`.
               Changing this creates a new Tap Mirror.
        :param pulumi.Input[_builtins.str] port_id: The Port ID of the Tap Mirror, this will be the source of
               the mirrored traffic, and this traffic will be tunneled into the GRE or ERSPAN
               v1 tunnel. The tunnel itself is not starting from this port. Changing this
               creates a new Tap Mirror.
        :param pulumi.Input[_builtins.str] remote_ip: The remote IP of the Tap Mirror, this will be the remote
               end of the GRE or ERSPAN v1 tunnel. Changing this creates a new Tap Mirror.
        :param pulumi.Input[_builtins.str] description: The human-readable description for the Tap Mirror.
               Changing this updates the description of the existing Tap Mirror.
        :param pulumi.Input[_builtins.str] name: The name of the Tap Mirror. Changing this updates the name of
               the existing Tap Mirror.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create an endpoint group. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               group.
        :param pulumi.Input[_builtins.str] tenant_id: The owner of the Tap Mirror. Required if admin wants to
               create a Tap Mirror for another project. Changing this creates a new Tap Mirror.
        """
        pulumi.set(__self__, "directions", directions)
        pulumi.set(__self__, "mirror_type", mirror_type)
        pulumi.set(__self__, "port_id", port_id)
        pulumi.set(__self__, "remote_ip", remote_ip)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @_builtins.property
    @pulumi.getter
    def directions(self) -> pulumi.Input['TaasTapMirrorV2DirectionsArgs']:
        """
        A block declaring the directions to be mirrored and their
        identifiers. One block has to be declared with at least one direction. Changing
        this creates a new Tap Mirror.
        """
        return pulumi.get(self, "directions")

    @directions.setter
    def directions(self, value: pulumi.Input['TaasTapMirrorV2DirectionsArgs']):
        pulumi.set(self, "directions", value)

    @_builtins.property
    @pulumi.getter(name="mirrorType")
    def mirror_type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of the mirroring, can be `gre` or `erspanv1`.
        Changing this creates a new Tap Mirror.
        """
        return pulumi.get(self, "mirror_type")

    @mirror_type.setter
    def mirror_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "mirror_type", value)

    @_builtins.property
    @pulumi.getter(name="portId")
    def port_id(self) -> pulumi.Input[_builtins.str]:
        """
        The Port ID of the Tap Mirror, this will be the source of
        the mirrored traffic, and this traffic will be tunneled into the GRE or ERSPAN
        v1 tunnel. The tunnel itself is not starting from this port. Changing this
        creates a new Tap Mirror.
        """
        return pulumi.get(self, "port_id")

    @port_id.setter
    def port_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "port_id", value)

    @_builtins.property
    @pulumi.getter(name="remoteIp")
    def remote_ip(self) -> pulumi.Input[_builtins.str]:
        """
        The remote IP of the Tap Mirror, this will be the remote
        end of the GRE or ERSPAN v1 tunnel. Changing this creates a new Tap Mirror.
        """
        return pulumi.get(self, "remote_ip")

    @remote_ip.setter
    def remote_ip(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "remote_ip", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The human-readable description for the Tap Mirror.
        Changing this updates the description of the existing Tap Mirror.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Tap Mirror. Changing this updates the name of
        the existing Tap Mirror.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create an endpoint group. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        group.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The owner of the Tap Mirror. Required if admin wants to
        create a Tap Mirror for another project. Changing this creates a new Tap Mirror.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tenant_id", value)


@pulumi.input_type
class _TaasTapMirrorV2State:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 directions: Optional[pulumi.Input['TaasTapMirrorV2DirectionsArgs']] = None,
                 mirror_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 remote_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering TaasTapMirrorV2 resources.
        :param pulumi.Input[_builtins.str] description: The human-readable description for the Tap Mirror.
               Changing this updates the description of the existing Tap Mirror.
        :param pulumi.Input['TaasTapMirrorV2DirectionsArgs'] directions: A block declaring the directions to be mirrored and their
               identifiers. One block has to be declared with at least one direction. Changing
               this creates a new Tap Mirror.
        :param pulumi.Input[_builtins.str] mirror_type: The type of the mirroring, can be `gre` or `erspanv1`.
               Changing this creates a new Tap Mirror.
        :param pulumi.Input[_builtins.str] name: The name of the Tap Mirror. Changing this updates the name of
               the existing Tap Mirror.
        :param pulumi.Input[_builtins.str] port_id: The Port ID of the Tap Mirror, this will be the source of
               the mirrored traffic, and this traffic will be tunneled into the GRE or ERSPAN
               v1 tunnel. The tunnel itself is not starting from this port. Changing this
               creates a new Tap Mirror.
        :param pulumi.Input[_builtins.str] project_id: Id of the OpenStack project.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create an endpoint group. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               group.
        :param pulumi.Input[_builtins.str] remote_ip: The remote IP of the Tap Mirror, this will be the remote
               end of the GRE or ERSPAN v1 tunnel. Changing this creates a new Tap Mirror.
        :param pulumi.Input[_builtins.str] tenant_id: The owner of the Tap Mirror. Required if admin wants to
               create a Tap Mirror for another project. Changing this creates a new Tap Mirror.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if directions is not None:
            pulumi.set(__self__, "directions", directions)
        if mirror_type is not None:
            pulumi.set(__self__, "mirror_type", mirror_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port_id is not None:
            pulumi.set(__self__, "port_id", port_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if remote_ip is not None:
            pulumi.set(__self__, "remote_ip", remote_ip)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The human-readable description for the Tap Mirror.
        Changing this updates the description of the existing Tap Mirror.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def directions(self) -> Optional[pulumi.Input['TaasTapMirrorV2DirectionsArgs']]:
        """
        A block declaring the directions to be mirrored and their
        identifiers. One block has to be declared with at least one direction. Changing
        this creates a new Tap Mirror.
        """
        return pulumi.get(self, "directions")

    @directions.setter
    def directions(self, value: Optional[pulumi.Input['TaasTapMirrorV2DirectionsArgs']]):
        pulumi.set(self, "directions", value)

    @_builtins.property
    @pulumi.getter(name="mirrorType")
    def mirror_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the mirroring, can be `gre` or `erspanv1`.
        Changing this creates a new Tap Mirror.
        """
        return pulumi.get(self, "mirror_type")

    @mirror_type.setter
    def mirror_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mirror_type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Tap Mirror. Changing this updates the name of
        the existing Tap Mirror.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="portId")
    def port_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Port ID of the Tap Mirror, this will be the source of
        the mirrored traffic, and this traffic will be tunneled into the GRE or ERSPAN
        v1 tunnel. The tunnel itself is not starting from this port. Changing this
        creates a new Tap Mirror.
        """
        return pulumi.get(self, "port_id")

    @port_id.setter
    def port_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "port_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Id of the OpenStack project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create an endpoint group. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        group.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="remoteIp")
    def remote_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The remote IP of the Tap Mirror, this will be the remote
        end of the GRE or ERSPAN v1 tunnel. Changing this creates a new Tap Mirror.
        """
        return pulumi.get(self, "remote_ip")

    @remote_ip.setter
    def remote_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "remote_ip", value)

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The owner of the Tap Mirror. Required if admin wants to
        create a Tap Mirror for another project. Changing this creates a new Tap Mirror.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tenant_id", value)


@pulumi.type_token("openstack:index/taasTapMirrorV2:TaasTapMirrorV2")
class TaasTapMirrorV2(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 directions: Optional[pulumi.Input[Union['TaasTapMirrorV2DirectionsArgs', 'TaasTapMirrorV2DirectionsArgsDict']]] = None,
                 mirror_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 remote_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a V2 Neutron Tap Mirror resource within OpenStack tap-as-a-service extension.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        tap_mirror1 = openstack.TaasTapMirrorV2("tap_mirror_1",
            mirror_type="erspanv1",
            port_id="a25290e9-1a54-4c26-a5b3-34458d122acc",
            remote_ip="172.18.1.15",
            directions={
                "in_": 1000,
                "out": 1001,
            })
        ```

        ## Import

        Tap Mirrors can be imported using the `id`, e.g.

        ```sh
        $ pulumi import openstack:index/taasTapMirrorV2:TaasTapMirrorV2 tap_mirror_1 0837b488-f0e2-4689-99b3-e3ed531f9b10
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: The human-readable description for the Tap Mirror.
               Changing this updates the description of the existing Tap Mirror.
        :param pulumi.Input[Union['TaasTapMirrorV2DirectionsArgs', 'TaasTapMirrorV2DirectionsArgsDict']] directions: A block declaring the directions to be mirrored and their
               identifiers. One block has to be declared with at least one direction. Changing
               this creates a new Tap Mirror.
        :param pulumi.Input[_builtins.str] mirror_type: The type of the mirroring, can be `gre` or `erspanv1`.
               Changing this creates a new Tap Mirror.
        :param pulumi.Input[_builtins.str] name: The name of the Tap Mirror. Changing this updates the name of
               the existing Tap Mirror.
        :param pulumi.Input[_builtins.str] port_id: The Port ID of the Tap Mirror, this will be the source of
               the mirrored traffic, and this traffic will be tunneled into the GRE or ERSPAN
               v1 tunnel. The tunnel itself is not starting from this port. Changing this
               creates a new Tap Mirror.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create an endpoint group. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               group.
        :param pulumi.Input[_builtins.str] remote_ip: The remote IP of the Tap Mirror, this will be the remote
               end of the GRE or ERSPAN v1 tunnel. Changing this creates a new Tap Mirror.
        :param pulumi.Input[_builtins.str] tenant_id: The owner of the Tap Mirror. Required if admin wants to
               create a Tap Mirror for another project. Changing this creates a new Tap Mirror.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TaasTapMirrorV2Args,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a V2 Neutron Tap Mirror resource within OpenStack tap-as-a-service extension.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        tap_mirror1 = openstack.TaasTapMirrorV2("tap_mirror_1",
            mirror_type="erspanv1",
            port_id="a25290e9-1a54-4c26-a5b3-34458d122acc",
            remote_ip="172.18.1.15",
            directions={
                "in_": 1000,
                "out": 1001,
            })
        ```

        ## Import

        Tap Mirrors can be imported using the `id`, e.g.

        ```sh
        $ pulumi import openstack:index/taasTapMirrorV2:TaasTapMirrorV2 tap_mirror_1 0837b488-f0e2-4689-99b3-e3ed531f9b10
        ```

        :param str resource_name: The name of the resource.
        :param TaasTapMirrorV2Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TaasTapMirrorV2Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 directions: Optional[pulumi.Input[Union['TaasTapMirrorV2DirectionsArgs', 'TaasTapMirrorV2DirectionsArgsDict']]] = None,
                 mirror_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 remote_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TaasTapMirrorV2Args.__new__(TaasTapMirrorV2Args)

            __props__.__dict__["description"] = description
            if directions is None and not opts.urn:
                raise TypeError("Missing required property 'directions'")
            __props__.__dict__["directions"] = directions
            if mirror_type is None and not opts.urn:
                raise TypeError("Missing required property 'mirror_type'")
            __props__.__dict__["mirror_type"] = mirror_type
            __props__.__dict__["name"] = name
            if port_id is None and not opts.urn:
                raise TypeError("Missing required property 'port_id'")
            __props__.__dict__["port_id"] = port_id
            __props__.__dict__["region"] = region
            if remote_ip is None and not opts.urn:
                raise TypeError("Missing required property 'remote_ip'")
            __props__.__dict__["remote_ip"] = remote_ip
            __props__.__dict__["tenant_id"] = tenant_id
            __props__.__dict__["project_id"] = None
        super(TaasTapMirrorV2, __self__).__init__(
            'openstack:index/taasTapMirrorV2:TaasTapMirrorV2',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            directions: Optional[pulumi.Input[Union['TaasTapMirrorV2DirectionsArgs', 'TaasTapMirrorV2DirectionsArgsDict']]] = None,
            mirror_type: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            port_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            remote_ip: Optional[pulumi.Input[_builtins.str]] = None,
            tenant_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'TaasTapMirrorV2':
        """
        Get an existing TaasTapMirrorV2 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: The human-readable description for the Tap Mirror.
               Changing this updates the description of the existing Tap Mirror.
        :param pulumi.Input[Union['TaasTapMirrorV2DirectionsArgs', 'TaasTapMirrorV2DirectionsArgsDict']] directions: A block declaring the directions to be mirrored and their
               identifiers. One block has to be declared with at least one direction. Changing
               this creates a new Tap Mirror.
        :param pulumi.Input[_builtins.str] mirror_type: The type of the mirroring, can be `gre` or `erspanv1`.
               Changing this creates a new Tap Mirror.
        :param pulumi.Input[_builtins.str] name: The name of the Tap Mirror. Changing this updates the name of
               the existing Tap Mirror.
        :param pulumi.Input[_builtins.str] port_id: The Port ID of the Tap Mirror, this will be the source of
               the mirrored traffic, and this traffic will be tunneled into the GRE or ERSPAN
               v1 tunnel. The tunnel itself is not starting from this port. Changing this
               creates a new Tap Mirror.
        :param pulumi.Input[_builtins.str] project_id: Id of the OpenStack project.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create an endpoint group. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               group.
        :param pulumi.Input[_builtins.str] remote_ip: The remote IP of the Tap Mirror, this will be the remote
               end of the GRE or ERSPAN v1 tunnel. Changing this creates a new Tap Mirror.
        :param pulumi.Input[_builtins.str] tenant_id: The owner of the Tap Mirror. Required if admin wants to
               create a Tap Mirror for another project. Changing this creates a new Tap Mirror.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TaasTapMirrorV2State.__new__(_TaasTapMirrorV2State)

        __props__.__dict__["description"] = description
        __props__.__dict__["directions"] = directions
        __props__.__dict__["mirror_type"] = mirror_type
        __props__.__dict__["name"] = name
        __props__.__dict__["port_id"] = port_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["region"] = region
        __props__.__dict__["remote_ip"] = remote_ip
        __props__.__dict__["tenant_id"] = tenant_id
        return TaasTapMirrorV2(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The human-readable description for the Tap Mirror.
        Changing this updates the description of the existing Tap Mirror.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def directions(self) -> pulumi.Output['outputs.TaasTapMirrorV2Directions']:
        """
        A block declaring the directions to be mirrored and their
        identifiers. One block has to be declared with at least one direction. Changing
        this creates a new Tap Mirror.
        """
        return pulumi.get(self, "directions")

    @_builtins.property
    @pulumi.getter(name="mirrorType")
    def mirror_type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of the mirroring, can be `gre` or `erspanv1`.
        Changing this creates a new Tap Mirror.
        """
        return pulumi.get(self, "mirror_type")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the Tap Mirror. Changing this updates the name of
        the existing Tap Mirror.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="portId")
    def port_id(self) -> pulumi.Output[_builtins.str]:
        """
        The Port ID of the Tap Mirror, this will be the source of
        the mirrored traffic, and this traffic will be tunneled into the GRE or ERSPAN
        v1 tunnel. The tunnel itself is not starting from this port. Changing this
        creates a new Tap Mirror.
        """
        return pulumi.get(self, "port_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        Id of the OpenStack project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create an endpoint group. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        group.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="remoteIp")
    def remote_ip(self) -> pulumi.Output[_builtins.str]:
        """
        The remote IP of the Tap Mirror, this will be the remote
        end of the GRE or ERSPAN v1 tunnel. Changing this creates a new Tap Mirror.
        """
        return pulumi.get(self, "remote_ip")

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Output[_builtins.str]:
        """
        The owner of the Tap Mirror. Required if admin wants to
        create a Tap Mirror for another project. Changing this creates a new Tap Mirror.
        """
        return pulumi.get(self, "tenant_id")

